InterruptGroup

Enum InterruptGroup 

pub enum InterruptGroup {
    Group0,
    Group1,
}
An interrupt group, without distinguishing between secure and non-secure.

This is used to select which group of interrupts to get, acknowledge and end.

Variants



Group0

Interrupt group 0.



Group1

Interrupt group 1.