pub enum InterruptGroup {
Group0,
Group1,
}Expand description
An interrupt group, without distinguishing between secure and non-secure.
This is used to select which group of interrupts to get, acknowledge and end.
Variants